summaryrefslogtreecommitdiff
path: root/TAO/examples/Callback_Quoter
diff options
context:
space:
mode:
authorAbdullah Sowayan <sowayan@users.noreply.github.com>2007-08-20 14:06:10 +0000
committerAbdullah Sowayan <sowayan@users.noreply.github.com>2007-08-20 14:06:10 +0000
commit27d69d07a29c8b4ebf30eb79f70da451d62d0039 (patch)
tree48e99b672f19a33e78342ab67820c5acbd930a0a /TAO/examples/Callback_Quoter
parentb59be1c3c77fb0cce55bf2956c07e54b92e1b389 (diff)
downloadATCD-27d69d07a29c8b4ebf30eb79f70da451d62d0039.tar.gz
Mon Aug 20 14:05:18 UTC 2007 Abdullah Sowayan <abdullah.sowayan@lmco.com>
Diffstat (limited to 'TAO/examples/Callback_Quoter')
-rw-r--r--TAO/examples/Callback_Quoter/Consumer_Input_Handler.h9
-rw-r--r--TAO/examples/Callback_Quoter/Consumer_Signal_Handler.h8
2 files changed, 5 insertions, 12 deletions
diff --git a/TAO/examples/Callback_Quoter/Consumer_Input_Handler.h b/TAO/examples/Callback_Quoter/Consumer_Input_Handler.h
index d64a6bcb66d..463a2c80271 100644
--- a/TAO/examples/Callback_Quoter/Consumer_Input_Handler.h
+++ b/TAO/examples/Callback_Quoter/Consumer_Input_Handler.h
@@ -61,9 +61,6 @@ public:
int quit_consumer_process (void);
// Ends the consumer process.
- friend class ACE_Shutup_GPlusPlus;
- // Turn off g++ warning
-
enum
{
// = TITLE
@@ -87,15 +84,13 @@ public:
// application.
};
-private:
+protected:
~Consumer_Input_Handler (void);
// the destructor.
+private:
Consumer_Handler *consumer_handler_;
// The Consumer_Handler object.
-
-
-
};
#endif /* CONSUMER_INPUT_HANDLER_H */
diff --git a/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.h b/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.h
index 04b3add1d77..eb641263435 100644
--- a/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.h
+++ b/TAO/examples/Callback_Quoter/Consumer_Signal_Handler.h
@@ -51,14 +51,12 @@ public:
// the handle_signal () returns < 0 this method will be executed
// automatically.
-private:
- friend class ACE_Shutup_GPlusPlus;
- // Turn off g++ warning
-
+protected:
~Consumer_Signal_Handler (void);
// Private destructor so that the signal handler is always created
// dynamically and hence the heap doesnt get corrupted.
+private:
int quit_on_signal (void);
// Exit gracefully on a signal.
@@ -51,14 +51,12 @@ public:
~Consumer_Signal_Handler (void);
- // Private destructor so that the signal handler is always created
+ // Protected destructor so that the signal handler is always created
// dynamically and hence the heap doesnt get corrupted.